#ifndef NT2_INCLUDE_CONSTANTS_MSEVEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MSEVEN_HPP_INCLUDED

#include <nt2/constant/include/constants/mseven.hpp>

#endif
